@@ -7,7 +7,7 @@
 
 .generateHulls <- function(xy, n=1) {
 	xy <- unique(  stats::na.omit(xy[, 1:2]) )
-    if (nrow(xy) < 3) { stop ('Insuficient number of points to make a hull; you need at least 3 unique points' ) }
+    if (nrow(xy) < 3) { stop ('Insufficient number of points to make a hull; you need at least 3 unique points' ) }
     n <- pmax(1, round(n))
     n <- pmin(n, floor(nrow(xy) / 3))
     n = unique(n)
